Boleto bancário

| 756 | Recibo do Sacado

Cedente | Agência/Código Cedente 3069/0000225 | CPF/CNPJ Cedente | Vencimento 06/05/2016
Sacado - CPF/CNPJ: | Nosso Número 0000003-5 | N. do documento 1212/1 | Data Documento 08/04/2016
Endereço Cedente - - - - | Valor Documento 97,50

Demonstrativo
Autenticação Mecânica

| 756 | 75691.30698 01000.022507 00000.350017 4 67860000009750

Local de pagamento Pagável Preferencialmente nas Cooperativas da Rede Sicoob ou Qualquer Banco até o Vencimento. | Vencimento 06/05/2016
Cedente | Agência/Código cedente 3069/0000225
Data do documento 08/04/2016 | N. do documento 1212/1 | Espécie doc DM | Aceite N | Data processamento 08/04/2016 | Nosso número 0000003-5
Uso do banco | Carteira 1 | Espécie R$ | Quantidade | Valor | (=) Valor documento 97,50
Instruções (Todas as informações deste bloqueto são de exclusiva responsabilidade do cedente) | (-) Descontos/Abatimentos
(-) Outras deduções
(+) Mora/Multa
(+) Outros acréscimos
(=) Valor cobrado

Sacado | - CPF/CNPJ: - - -
Sacador / Avalista | Código de baixa
| Autenticação Mecânica / Ficha de Compensação